'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.runProofUtilsUnitTests = runProofUtilsUnitTests;
exports.runProofServicesUnitTests = runProofServicesUnitTests;
exports.runProofsUnitTests = runProofsUnitTests;

var _blueTape = require('blue-tape');

var _blueTape2 = _interopRequireDefault(_blueTape);

var _tape = require('tape');

var _tape2 = _interopRequireDefault(_tape);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _fetchMock = require('fetch-mock');

var _fetchMock2 = _interopRequireDefault(_fetchMock);

var _lib = require('../../../lib');

var _sampleData = require('./sampleData');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function mockRequests() {
  var naval = _sampleData.sampleVerifications.naval;
  var larry = _sampleData.sampleVerifications.larry;

  _fetchMock2.default.get(naval.facebook.url, naval.facebook.body);
  _fetchMock2.default.get(naval.github.url, naval.github.body);
  _fetchMock2.default.get(naval.twitter.url, naval.twitter.body);
  _fetchMock2.default.get(larry.facebook.url, larry.facebook.body);
}

function testProofs(profile, username, totalProofs) {
  mockRequests();

  (0, _blueTape2.default)('Profiles', function (t) {
    return (0, _lib.validateProofs)(profile, username).then(function (proofs) {
      t.ok(proofs, 'Proofs must have been created');
      t.equal(proofs instanceof Array, true, "Proofs should be an Array");
      t.equal(proofs.length, totalProofs, "Should have a proof for each of the 3 claimed accounts");
      _fetchMock2.default.restore();
    });
  });
}

function runProofUtilsUnitTests() {
  (0, _tape2.default)('containsValidProofStatement', function (t) {
    t.plan(8);

    var naval = _sampleData.sampleVerifications.naval;

    t.equal((0, _lib.containsValidProofStatement)(naval.facebook.body, 'naval.id'), true, "Facebook post body should contain valid proof statement for naval.id");
    t.equal((0, _lib.containsValidProofStatement)(naval.github.body, 'naval.id'), true, "Github gist post body should contain valid proof statement for naval.id");
    t.equal((0, _lib.containsValidProofStatement)(naval.twitter.body, 'naval.id'), true, "Twitter post body should contain valid proof statement for naval.id");

    var larry = _sampleData.sampleVerifications.larry;

    t.equal((0, _lib.containsValidProofStatement)(naval.facebook.body, 'larry.id'), false, "Github gist post body should not contain valid proof statement for larry.id");
    t.equal((0, _lib.containsValidProofStatement)(naval.github.body, 'larry.id'), false, "Github gist post body should not contain valid proof statement for larry.id");
    t.equal((0, _lib.containsValidProofStatement)(naval.twitter.body, 'larry.id'), false, "Github gist post body should not contain valid proof statement for larry.id");
    t.equal((0, _lib.containsValidProofStatement)(larry.facebook.body, 'larry.id'), true, "Facebook post body should contain valid proof statement for larry.id");

    t.throws(function () {
      (0, _lib.containsValidProofStatement)(larry.facebook.body, 'larry');
    }, /Error/, "Using non-fully qualified blockstack name should throw exception");
  });
}

function runProofServicesUnitTests() {
  (0, _tape2.default)('normalize Facebook URLs', function (t) {
    t.plan(6);
    t.equal(_lib.profileServices.facebook.normalizeFacebookUrl({
      service: 'facebook',
      proof_url: "https://www.facebook.com/navalr/posts/10152190734077261",
      identifier: "navalr"
    }), "https://www.facebook.com/navalr/posts/10152190734077261", "Facebook URL should be normalized");
    t.equal(_lib.profileServices.facebook.normalizeFacebookUrl({
      service: 'facebook',
      proof_url: "https://facebook.com/navalr/posts/10152190734077261",
      identifier: "navalr"
    }), "https://www.facebook.com/navalr/posts/10152190734077261", "Facebook URL should be normalized");
    t.equal(_lib.profileServices.facebook.normalizeFacebookUrl({
      service: 'facebook',
      proof_url: "https://www.facebook.com/larrysalibra/posts/10100341028448093",
      identifier: "larrysalibra"
    }), "https://www.facebook.com/larrysalibra/posts/10100341028448093", "Facebook URL should be normalized");
    t.notEqual(_lib.profileServices.facebook.normalizeFacebookUrl({
      service: 'facebook',
      proof_url: "https://www.facebook.com/larry.salibra/posts/10100341028448093",
      identifier: "larry.salibra"
    }), "https://www.facebook.com/larrysalibra/posts/10100341028448093", "Facebook URL should be normalized");
    t.notEqual(_lib.profileServices.facebook.normalizeFacebookUrl({
      service: 'facebook',
      proof_url: "https://facebook.com/larry.salibra/posts/10100341028448093",
      identifier: "larry.salibra"
    }), "https://www.facebook.com/larrysalibra/posts/10100341028448093", "Facebook URL should be normalized");
    t.equal(_lib.profileServices.facebook.normalizeFacebookUrl({
      service: 'facebook',
      proof_url: "https://facebook.com/larrysalibra/posts/10100341028448093",
      identifier: "larrysalibra"
    }), "https://www.facebook.com/larrysalibra/posts/10100341028448093", "Facebook URL should be normalized");
  });

  (0, _tape2.default)('get proof url', function (t) {
    t.plan(7);
    t.equal(_lib.profileServices.facebook.getProofUrl(_sampleData.sampleProofs.naval[1]), "https://www.facebook.com/navalr/posts/10152190734077261", "Facebook proof URL should match reference");
    t.equal(_lib.profileServices.github.getProofUrl(_sampleData.sampleProofs.naval[2]), "https://gist.github.com/navalr/f31a74054f859ec0ac6a", "Facebook proof URL should match reference");
    t.equal(_lib.profileServices.twitter.getProofUrl(_sampleData.sampleProofs.naval[0]), "https://twitter.com/naval/status/486609266212499456", "Facebook proof URL should match reference");
    t.equal(_lib.profileServices.facebook.getProofUrl(_sampleData.sampleProofs.larry[0]), "https://www.facebook.com/larry.salibra/posts/10100341028448093", "Facebook proof URL should match reference");

    t.throws(function () {
      var notLarry = Object.assign({}, _sampleData.sampleProofs.larry[0], {
        proof_url: 'https://www.facebook.com/not.larry/posts/10100341028448093'
      });
      _lib.profileServices.facebook.getProofUrl(notLarry);
    }, /Error/, 'Not having claimed account identifier in Facebook proof URL should throw exception');

    t.throws(function () {
      var notNavalTwitter = Object.assign({}, _sampleData.sampleProofs.naval[0], {
        proof_url: 'https://twitter.com/not_naval/status/486609266212499456'
      });
      _lib.profileServices.twitter.getProofUrl(notNavalTwitter);
    }, /Error/, 'Not having claimed account identifier in Twitter proof URL should throw exception');

    t.throws(function () {
      var notNavalGithub = Object.assign({}, _sampleData.sampleProofs.naval[2], {
        proof_url: 'https://gist.github.com/not_naval/f31a74054f859ec0ac6a'
      });
      _lib.profileServices.github.getProofUrl(notNavalGithub);
    }, /Error/, 'Not having claimed account identifier in Github proof URL should throw exception');
  });
}

function runProofsUnitTests() {
  // Proof utils
  runProofUtilsUnitTests();
  // Proof services
  runProofServicesUnitTests();
  // Proof HTML
  testProofs(_sampleData.sampleProfiles.naval, "naval.id", 3);
  testProofs(_sampleData.sampleProfiles.larry, "larry.id", 1);
}